@@ -2,9 +2,22 @@ import sys
 from urllib import request
 from tabulate import tabulate
 
-def search () :
+def usage():
+	print("Usage:\n  pip_search <keywords>")
 
-	f = request.urlopen('https://pypi.org/search/?q=%s' % sys.argv[1])
+def main():
+	if (
+		len(sys.argv) < 2 or "-h" in sys.argv
+		or "--help" in sys.argv or "--usage" in sys.argv
+	):
+		usage()
+	else:
+		search()
+
+def search () :
+	keyword = ' '.join(sys.argv[1::]).replace(' ', '+')
+
+	f = request.urlopen('https://pypi.org/search/?q=%s' % keyword)
 	raw_text=str(f.read())
 
 	raw_names=raw_text.split('<span class="package-snippet__name">')[1:-2]
@@ -23,4 +36,4 @@ def search () :
 	print(tabulate(header+rows))
 
 if __name__ == '__main__':
-    search()
\ No newline at end of file
+	main()
\ No newline at end of file
